# $NetBSD: bsd.prefs.mk,v 1.118 2003/07/13 13:27:18 grant Exp $
#
# Make file, included to get the site preferences.  Should
# only be included by package Makefiles before any .if defined()
# statements or modifications to "passed" variables (CFLAGS, LDFLAGS, ...),
# to make sure any variables defined in /etc/mk.conf, $MAKECONF, or
# the system defaults (sys.mk and bsd.own.mk) are used.
#
# The goal of this file is to establish a well-defined environment for
# the build system. Its is now regarded as bad style to set variables
# only if they are not yet set, i.e. assginments like
#
#   VAR?=VALUE
# 
# The problem is that this makes the build system very dependent on the 
# environment variables (which might be cool for experts, but is too
# ambitious for beginners). To change a certain variable for a single
# run of "make" define it on the command-line, e.g.
#
#   bmake VAR=VALUE TARGET
#
# This implicitly overrides all assignments found in parsed makefiles.
# Permanent changes should go to godi.conf. Another way to override
# variables is to set GODI_OVERRIDE_PREFS. This file name is included
# at the end of bsd.prefs.mk, and thus can change all variables again.

# Note: All the .undef statements don't have an effect on the "bmake"
# implementation, only on the Godi_make module. This is work in progress.
# In the same way, GODI_MAKE_ENV is only interpreted by the Godi_make
# module.

# Do not recursively include mk.conf, redefine OPSYS, include bsd.own.mk, etc.
GODI_MAKE_ENV += BSD_PKG_MK PREFIX GODI_OVERRIDE_PREFS
.ifndef BSD_PKG_MK

# Let mk.conf know that this is pkgsrc.
BSD_PKG_MK=1
__PREFIX_SET__:=${PREFIX}

GODI_MAKE_ENV += MAKEFLAGS GODI_CONF PATH

#----------------------------------------------------------------------
# Detect the type of the system
#----------------------------------------------------------------------

# This must happen before godi.conf is included such that the variables
# can be changed in godi.conf.

# Type detection is now done at configuration time, and the result
# is only loaded:

.include "${.PARSEDIR}/systype.mk"

MAKEFLAGS+=		OPSYS="${OPSYS}"
MAKEFLAGS+=		OS_VERSION="${OS_VERSION}"
MAKEFLAGS+=		OS_MAJOR_VERSION="${OS_MAJOR_VERSION}"
MAKEFLAGS+=		MACHINE="${MACHINE}"
MAKEFLAGS+=		MACHINE_ARCH="${MACHINE_ARCH}"
MAKEFLAGS+=		MACHINE_GNU_ARCH="${MACHINE_GNU_ARCH}"
MAKEFLAGS+=		MACHINE_PLATFORM="${MACHINE_PLATFORM}"
MAKEFLAGS+=		MACHINE_GNU_PLATFORM="${MACHINE_GNU_PLATFORM}"
MAKEFLAGS+=		LOWER_OPSYS="${LOWER_OPSYS}"
MAKEFLAGS+=		LOWER_OS_VERSION="${LOWER_OS_VERSION}"
MAKEFLAGS+=		LOWER_VENDOR="${LOWER_VENDOR}"
MAKEFLAGS+=		LOWER_ARCH="${LOWER_ARCH}"
MAKEFLAGS+=		ABI="${ABI}"

#----------------------------------------------------------------------
# Load OS definition
#----------------------------------------------------------------------

# Further variables:
.undef PKGLOCALEDIR
.undef CPP_PRECOMP_FLAGS
.undef DEF_UMASK
.undef EXPORT_SYMBOLS_LDFLAGS
.undef ULIMIT_CMD_datasize
.undef ULIMIT_CMD_stacksize
.undef ULIMIT_CMD_memorysize
.undef _OPSYS_WHOLE_ARCHIVE_FLAG
.undef _OPSYS_NO_WHOLE_ARCHIVE_FLAG
.undef _STRIPFLAG_CC
.undef _STRIPFLAG_INSTALL
.undef DEBUG_FLAGS


EXEC_SUFFIX=
# When the OS requires that native executables have a certain suffix
# (think .exe)


# The list of programs found by the "configure" script. The names of
# the variables containing the path to the program are enumerated:
ESSENTIAL_PROGRAMS=	\
	AWK		\
	BASENAME	\
	BZCAT		\
	CAT		\
	CHMOD		\
	CMP		\
	CP		\
	CUT		\
	DATE		\
	DC		\
	DIRNAME		\
	ECHO		\
	EGREP		\
	EXPR		\
	FALSE		\
	FGREP		\
	FILE_CMD	\
	FIND		\
	GREP		\
	GUNZIP_EXE	\
	GUNZIP_CMD      \
	GZIP_EXE	\
	GZIP		\
	GZIP_CMD		\
	GZCAT		\
	HEAD		\
	HOSTNAME_CMD	\
	ID		\
	LDCONFIG	\
	LDD		\
	LN		\
	LS		\
	M4		\
	MKDIR_EXE	\
	MKDIR           \
	MV		\
	PATCH		\
	PRINTF		\
	PS		\
	PWD_CMD		\
	RM		\
	RMDIR		\
	SED		\
	SETENV		\
	SH		\
	SORT		\
	TAIL		\
	TEE		\
	TEST		\
	TOUCH		\
	TR		\
	TRUE		\
	TSORT		\
	TYPE		\
	WC		\
	XARGS_EXE	\
	GCC_EXE		\
	AR_EXE		\
	RANLIB_EXE	\
	NM_EXE		\
	CPP_EXE         \
	STRIP_EXE

# Load the OS-specific definitions for program variables.  Default to loading
# "Generic" if an OS-specific file doesn't exist.
.if exists(${.PARSEDIR}/defs.${OPSYS}.mk)
.include "${.PARSEDIR}/defs.${OPSYS}.mk"
.elif exists(${.PARSEDIR}/defs.Generic.mk)
.include "${.PARSEDIR}/defs.Generic.mk"
.endif

# Set ELF_RPATH=no if not defined
.ifndef ELF_RPATH
ELF_RPATH=              no
.endif

# If there is ELF_RPATH_FLAG, set also RPATH_FLAG for backwards
# compatibility.
.ifdef ELF_RPATH_FLAG
RPATH_FLAG=		${ELF_RPATH_FLAG}
.endif

# WHOLE_ARCHIVE_FLAG and NO_WHOLE_ARCHIVE_FLAG publically export the
# linker flags to extract all symbols from a static archive.
WHOLE_ARCHIVE_FLAG=	${_OPSYS_WHOLE_ARCHIVE_FLAG}
NO_WHOLE_ARCHIVE_FLAG=	${_OPSYS_NO_WHOLE_ARCHIVE_FLAG}

#----------------------------------------------------------------------
# Initialize binary package tools
#----------------------------------------------------------------------

# PAX, GTAR are usually already set in defs.OPSYS.mk. Because we know
# we have our own versions, override these variables here.

PAX=		${LOCALBASE}/bin/godi_pax
GTAR=		${LOCALBASE}/bin/godi_tar
PKG_TOOLS_BIN= 	${LOCALBASE}/sbin

DIGEST=		${LOCALBASE}/bin/godi_digest
MAKEFLAGS+=	DIGEST="${DIGEST}"

PKG_DEP=	${PKG_TOOLS_BIN}/godi_console dep
PKG_PTOOL=	${PKG_TOOLS_BIN}/godi_console ptool
PKG_DELETE=	${PKG_TOOLS_BIN}/godi_console delete

PKG_DBDIR=	${GODI_DBDIR}
# compatibility with NetBSD

FETCH_CMD=		${PKG_TOOLS_BIN}/godi_console wget
FETCH_BEFORE_ARGS=
FETCH_AFTER_ARGS=
.undef PASSIVE_FETCH

#----------------------------------------------------------------------
# Set up the build system
#----------------------------------------------------------------------

# This is the ../.. directory relative to the package directory
# (usually LOCALBASE/build).
_PKGSRCDIR=		${.CURDIR:C|/[^/]*/[^/]*$||}

# The package directory relative to _PKGSRCDIR.
PKGPATH=		${.CURDIR:C|.*/([^/]*/[^/]*)$|\1|}

DISTDIR=		${_PKGSRCDIR}/distfiles
PACKAGES=		${_PKGSRCDIR}/packages
TEMPLATES=		${_PKGSRCDIR}/templates

PATCHDIR=		${.CURDIR}/patches
SCRIPTDIR=		${.CURDIR}/scripts
FILESDIR=		${.CURDIR}/files
PKGDIR=			${.CURDIR}
# Where to find the definition of the package.

BUILD_DIR=		${.CURDIR}
# Where to build the package. May be overriden.

WRKDIR_BASENAME=	work
WRKDIR=			${BUILD_DIR}/${WRKDIR_BASENAME}

# Used to print all the '===>' style prompts - override this to turn them off.
ECHO_MSG=		${ECHO}

# Used to print error messages
ERROR_MSG=		${ECHO}

TOUCH_FLAGS=
# Flags for ${TOUCH} to create the cookies.

DEF_UMASK=		022

#----------------------------------------------------------------------
# Defaults for installing files
#----------------------------------------------------------------------

BINMODE=	555
# Mode for executable files (modulo umask)

NONBINMODE=    	444
# Mode for non-executable files (modulo umask)

MANMODE=       	${NONBINMODE}
# Mode for manual pages
MANINSTALL=    	maninstall catinstall
# Which types of manpages to install

INFOMODE=      	${NONBINMODE}
# Mode for info pages

LIBMODE=       	${NONBINMODE}
# Mode for libraries

DOCMODE=       	${NONBINMODE}
# Mode for documentation files

NLSMODE=       	${NONBINMODE}
# Mode for localization files

LOCALEMODE=    	${NONBINMODE}
# Mode for locale files

SHAREMODE=	${DOCMODE}
# Mode for shared data files

PKGDIRMODE=	755
# Mode for directories

#----------------------------------------------------------------------
# Undef variables
#----------------------------------------------------------------------

# Ensure these vars are undefined for a sane environment.

.undef SHLIB_HANDLING
.undef PKGBASE
.undef PKGNAME
.undef PKGNAME_NOREV
.undef PKGREVISION
.undef PKGVERSION
.undef PKGWILDCARD
.undef SVR4_PKGNAME
.undef DISTNAME
.undef _DISTDIR
.undef DIST_SUBDIR
.undef USE_GMAKE
.undef DIGEST_ALGORITHM
.undef SHCOMMENT
.undef DISTINFO_FILE
.undef COMMENT
.undef MAINTAINER
.undef CATEGORIES

.undef DEPENDS
.undef BUILD_DEPENDS
.undef SUGGESTS_DEPENDS

.undef HAS_CONFIGURE
.undef GNU_CONFIGURE
.undef CONFIGURE_ENV
.undef CONFIGURE_DIRS
.undef CONFIGURE_SCRIPT
.undef CONFIGURE_ARGS
.undef GNU_CONFIGURE_PREFIX
.undef PKG_SYSCONFVAR
.undef PKG_SYSCONFBASE
.undef PKG_SYSCONFDIR
.undef PKG_SYSCONFSUBDIR
.undef CONFIG_GUESS_OVERRIDE
.undef CONFIG_SUB_OVERRIDE
.undef _CONFIGURE_PREREQ
.undef _CONFIGURE_POSTREQ

.undef BUILD_DIRS
.undef TEST_DIRS
.undef INSTALL_DIRS
.undef AUTOGENERATE_PLIST

.undef IGNOREFILES
.undef PATCHFILES

.undef SCRIPTS_ENV
.undef MAKE_ENV
.undef MAKE_FLAGS
.undef MAKEFILE
.undef FIX_RPATH
.undef EXTRACT_SUFX
.undef WRKSRC
.undef DESCR_SRC
.undef PLIST_SRC
.undef PLIST_SUBST
.undef INSTALL_FILE
.undef DEINSTALL_FILE
.undef MESSAGE
.undef MESSAGE_SRC
.undef MESSAGE_SUBST
.undef MESSAGE_SUBST_SED
.undef CONFLICTS
.undef PKG_ARGS_COMMON
.undef PKG_PRESERVE
.undef PKG_ARGS_INSTALL
.undef PKG_ARGS_BINPKG
.undef PKG_SUFX
.undef SMART_MESSAGES
.undef PKG_FAIL_REASON
.undef ALL_TARGET
.undef INSTALL_TARGET
.undef TEST_TARGET
.undef _USE_RPATH
.undef DISTFILES
.undef ALLFILES
.undef CKSUMFILES
.undef DECOMPRESS_CMD
.undef EXTRACT_ONLY
.undef EXTRACT_ELEMENTS
.undef EXTRACT_USING_PAX
.undef EXTRACT_CMD
.undef PKGREPOSITORYSUBDIR
.undef BUILD_DEFS
.undef PKGSRC_RUN_TEST
.undef USE_NEW_TEXINFO
.undef FORCE_PKG_REGISTER
.undef SU_CMD_PATH_APPEND
.undef PACKAGE_NAME_TYPE
.undef PACKAGE_DEPENDS_WITH_PATTERNS
.undef PACKAGE_DEPENDS_QUICK
.undef USE_CTIME

.undef MANZ
.undef MANCOMPRESSED
.undef MANCOMPRESSED_IF_MANZ

.undef GENERATE_PLIST
.undef PKG_VERBOSE
.undef PKGCONFIG_OVERRIDE

.undef NO_CHECKSUM
.undef NO_CONFIGURE
.undef NO_BUILD
.undef NO_INSTALL
.undef NO_PACKAGE
.undef NO_DEPENDS
.undef SKIP_SILENT
.undef NO_PKG_REGISTER

.undef WRKOBJDIR
.undef OBJHOSTNAME
.undef OBJMACHINE

.undef MASTER_SORT
.undef MASTER_SORT_REGEX
.undef MASTER_SITE_OVERRIDE
.undef LOCALPATCHES
.undef PATCH_FUZZ_FACTOR
.undef PATCH_DEBUG

.undef LINK_ALL_LIBGCC_HACK
.undef PTHREAD_CFLAGS
.undef PTHREAD_LDFLAGS
.undef COPY
.undef UNLIMIT_RESOURCES
.undef _FETCH_MESSAGE

.undef SEARCH_LIBS
.undef SEARCH_LIBS_DEFAULT
.undef SEARCH_LIBS_OVERRIDE
.undef PLIST_GODI_FILE
.undef GODI_PATH
.undef GODI_PLIST

.undef VARNAMES
.undef SELF_UPDATE_PKG

#----------------------------------------------------------------------
# Set master sites
#----------------------------------------------------------------------

# Popular master sites
MASTER_SITE_XCONTRIB=	\
	ftp://uiarchive.uiuc.edu/pub/ftp/ftp.x.org/contrib/ \
	ftp://sunsite.doc.ic.ac.uk/packages/X11/contrib/ \
	ftp://ftp.gwdg.de/pub/x11/x.org/contrib/ \
	ftp://ftp.sunet.se/pub/X11/contrib/ \
	ftp://sunsite.sut.ac.jp/pub/archives/X11/contrib/ \
	ftp://sunsite.icm.edu.pl/pub/X11/contrib/ \
	ftp://ftp.task.gda.pl/mirror/ftp.x.org/contrib/ \
	ftp://ftp.ntua.gr/pub/X11/contrib/ \
	ftp://sunsite.cnlab-switch.ch/mirror/X11/contrib/ \
	ftp://ftp.cica.es/pub/X/contrib/ \
	ftp://ftp.unicamp.br/pub/X11/contrib/ \
	ftp://ftp.x.org/contrib/

MASTER_SITE_GNU=	\
	ftp://ftp.gnu.org/pub/gnu/ \
	ftp://ftp.gwdg.de/pub/gnu/ \
	ftp://ftp.progsoc.uts.edu.au/pub/gnu/ \
	ftp://gatekeeper.dec.com/pub/GNU/ \
	ftp://ftp.uu.net/archive/systems/gnu/ \
	ftp://ftp.de.uu.net/pub/gnu/ \
	ftp://ftp.funet.fi/pub/gnu/prep/ \
	ftp://ftp.leo.org/pub/comp/os/unix/gnu/ \
	ftp://ftp.digex.net/pub/gnu/ \
	ftp://ftp.wustl.edu/mirrors/gnu/ \
	ftp://ftp.kddlabs.co.jp/pub/gnu/ \
	ftp://ftp.dti.ad.jp/pub/GNU/ \
	ftp://ftp.mirror.ac.uk/sites/ftp.gnu.org/gnu/ \
	ftp://sunsite.org.uk/Mirrors/ftp.gnu.org/pub/gnu/ \
	ftp://ftp.informatik.hu-berlin.de/pub/gnu/ \
	ftp://ftp.rediris.es/mirror/gnu/ \
	ftp://ftp.lip6.fr/pub/gnu/ \
	ftp://ftp.tuwien.ac.at/linux/gnu/gnusrc/ \
	ftp://ftp.chg.ru/pub/gnu/

MASTER_SITE_GNUSTEP=	\
	ftp://ftp.gnustep.org/pub/gnustep/ \
	http://public.planetmirror.com.au/pub/gnustep/gnustep/ \
	http://www.peanuts.org/peanuts/Mirrors/GNUstep/gnustep/ \
	ftp://archive.progeny.com/gnustep/ \
	http://archive.progeny.com/gnustep/ \
	ftp://ftp.easynet.nl/mirror/GNUstep/ \
	http://ftp.easynet.nl/mirror/GNUstep/

MASTER_SITE_PERL_CPAN=	\
	ftp://cpan.pair.com/pub/CPAN/modules/by-module/ \
	ftp://mirrors.cloud9.net/pub/mirrors/CPAN/modules/by-module/ \
	ftp://ftp.sunet.se/pub/lang/perl/CPAN/modules/by-module/ \
	ftp://ftp.uvsq.fr/pub/perl/CPAN/modules/by-module/ \
	ftp://ftp.gmd.de/mirrors/CPAN/modules/by-module/ \
	ftp://ftp.tuwien.ac.at/pub/CPAN/modules/by-module/ \
	ftp://cpan.perl.org/CPAN/modules/by-module/

MASTER_SITE_R_CRAN=	\
	http://cran.r-project.org/src/ \
	ftp://cran.r-project.org/pub/R/src/ \
	http://cran.at.r-project.org/src/ \
	ftp://cran.at.r-project.org/pub/R/src/ \
	http://cran.dk.r-project.org/src/ \
	http://cran.ch.r-project.org/src/ \
	http://cran.uk.r-project.org/src/ \
	http://cran.us.r-project.org/src/ \
	http://lib.stat.cmu.edu/R/CRAN/src/ \
	ftp://ftp.biostat.washington.edu/mirrors/R/CRAN/src/ \
	http://cran.stat.wisc.edu/src/ \
	http://SunSITE.auc.dk/R/src/ \
	http://www.stat.unipg.it/pub/stat/statlib/R/CRAN/src/ \
	ftp://ftp.u-aizu.ac.jp/pub/lang/R/CRAN/src/ \
	ftp://dola.snu.ac.kr/pub/R/CRAN/src/ \
	http://stat.ethz.ch/CRAN/src/ \
	http://www.stats.bris.ac.uk/R/src/

MASTER_SITE_TEX_CTAN= \
	ftp://ftp.wustl.edu/packages/TeX/ \
	ftp://ftp.funet.fi/pub/TeX/CTAN/ \
	ftp://ftp.tex.ac.uk/public/ctan/tex-archive/ \
	ftp://ftp.dante.de/tex-archive/

MASTER_SITE_SUNSITE=	\
	ftp://sunsite.unc.edu/pub/Linux/ \
	ftp://ftp.infomagic.com/pub/mirrors/linux/sunsite/ \
	ftp://ftp.chg.ru/pub/Linux/sunsite/ \
	ftp://ftp.is.co.za/linux/sunsite/ \
	ftp://ftp.kddlabs.co.jp/Linux/metalab.unc.edu/ \
	ftp://ftp.kobe-u.ac.jp/pub/Linux/metalab.unc.edu/ \
	ftp://ftp.cse.cuhk.edu.hk/pub4/Linux/ \
	ftp://ftp.icm.edu.pl/pub/Linux/sunsite/ \
	ftp://ftp.nvg.ntnu.no/pub/mirrors/metalab.unc.edu/ \
	ftp://ftp.uvsq.fr/pub5/linux/sunsite/ \
	ftp://ftp.lip6.fr/pub/linux/sunsite/ \
	ftp://ftp.uni-stuttgart.de/pub/mirror/sunsite.unc.edu/pub/Linux/ \
	ftp://ftp.uni-magdeburg.de/pub/mirror/linux/ftp.metalab.unc.edu/ \
	ftp://ftp.uni-jena.de/pub/linux/MIRROR.sunsite/ \
	ftp://ftp.fu-berlin.de/unix/linux/mirrors/sunsite.unc.edu/ \
	ftp://ftp.cs.tu-berlin.de/pub/linux/Mirrors/sunsite.unc.edu/ \
	ftp://sunsite.cnlab-switch.ch/mirror/linux/sunsite/ \
	ftp://ftp.tuwien.ac.at/pub/linux/ibiblio/ \
	ftp://ftp.unicamp.br/pub/systems/Linux/

MASTER_SITE_GNOME=	\
	ftp://ftp.gnome.org/pub/GNOME/ \
	ftp://ftp.sunet.se/pub/X11/GNOME/ \
	ftp://ftp.tuwien.ac.at/hci/GNOME/ \
	ftp://ftp.cse.buffalo.edu/pub/Gnome/ \
	ftp://ftp.tuwien.ac.at/linux/gnome.org/ \
	ftp://ftp.dti.ad.jp/pub/X/gnome/ \
	ftp://ftp.kddlabs.co.jp/pub/GNOME/ \
	ftp://ftp.chg.ru/pub/X11/gnome/ \
	ftp://ftp.dataplus.se/pub/linux/gnome/ \
	ftp://ftp.dit.upm.es/linux/gnome/ \
	ftp://ftp.mirror.ac.uk/sites/ftp.gnome.org/pub/GNOME/

MASTER_SITE_SOURCEFORGE=	\
	http://easynews.dl.sourceforge.net/sourceforge/ \
	http://internap.dl.sourceforge.net/sourceforge/ \
	http://puzzle.dl.sourceforge.net/sourceforge/ \
	http://peterhost.dl.sourceforge.net/sourceforge/ \
	http://nchc.dl.sourceforge.net/sourceforge/ \
	http://ovh.dl.sourceforge.net/sourceforge/ \
	http://citkit.dl.sourceforge.net/sourceforge/ \
	http://jaist.dl.sourceforge.net/sourceforge/ \
	http://optusnet.dl.sourceforge.net/sourceforge/ \
	http://surfnet.dl.sourceforge.net/sourceforge/ \
	http://umn.dl.sourceforge.net/sourceforge/ \
	http://keihanna.dl.sourceforge.net/sourceforge/ \
	http://kent.dl.sourceforge.net/sourceforge/ \
	http://switch.dl.sourceforge.net/sourceforge/ \
	http://heanet.dl.sourceforge.net/sourceforge/ \
	http://ufpr.dl.sourceforge.net/sourceforge/

MASTER_SITE_SUSE=	\
	ftp://fr2.rpmfind.net/linux/SuSE-Linux/suse/${MACHINE_ARCH}/${SUSE_VERSION}/suse/ \
	ftp://ftp.duth.gr/pub/suse/${MACHINE_ARCH}/${SUSE_VERSION}/suse/ \
	ftp://ftp.kddlabs.co.jp/Linux/packages/SuSE/suse/${MACHINE_ARCH}/${SUSE_VERSION}/suse/ \
	ftp://sunsite.cnlab-switch.ch/mirror/SuSE/suse/${MACHINE_ARCH}/${SUSE_VERSION}/suse/ \
	ftp://ftp.mirror.ac.uk/sites/ftp.suse.com/pub/suse/${MACHINE_ARCH}/${SUSE_VERSION}/suse/ \
	ftp://mirror.mcs.anl.gov/pub/ftp.suse.com/${MACHINE_ARCH}/${SUSE_VERSION}/suse/

MASTER_SITE_MOZILLA=	\
	ftp://ftp.mozilla.org/pub/mozilla/releases/ \
	ftp://ftp.fu-berlin.de/pub/unix/network/www/mozilla/releases/ \
	ftp://sunsite.utk.edu/pub/netscape-source/ \
	ftp://ftp.informatik.uni-bonn.de/pub/www/mozilla/ \
	ftp://ftp-stud.fht-esslingen.de/pub/Mirrors/ftp.mozilla.org/pub/ \
	ftp://sunsite.auc.dk/pub/mozilla/ \
	ftp://ftp.funet.fi/pub/mirrors/ftp.mozilla.org/pub/ \
	ftp://ftp.sunsite.kth.se/archive/www/ftp.mozilla.org/ \
	http://public.planetmirror.com.au/pub/mozilla/releases/ \
	ftp://ftp2.sinica.edu.tw/pub3/www/mozilla/ \
	ftp://ftp.is.co.za/networking/info-service/www/clients/netscape/mozilla/ \
	ftp://ftp.rediris.es/mirror/mozilla/ \
	ftp://ftp.chg.ru/pub/WWW/mozilla/

MASTER_SITE_XEMACS=	\
	ftp://ftp.xemacs.org/pub/xemacs/ \
	ftp://ftp.dti.ad.jp/pub/unix/editor/xemacs/ \
	ftp://ftp.jaist.ac.jp/pub/GNU/xemacs/ \
	ftp://ftp.pasteur.fr/pub/computing/xemacs/ \
	ftp://ftp.tu-darmstadt.de/pub/editors/xemacs/ \
	http://public.planetmirror.com.au/pub/xemacs/ \
	ftp://mirror.aarnet.edu.au/pub/xemacs/ \
	ftp://mirror.cict.fr/xemacs/ \
	ftp://mirror.nucba.ac.jp/mirror/xemacs/ \
	ftp://ring.aist.go.jp/pub/text/xemacs/ \
	ftp://ring.asahi-net.or.jp/pub/text/xemacs/

MASTER_SITE_APACHE=	\
	http://www.apache.org/dist/ \
	http://mirrors.midco.net/pub/apache.org/ \
	http://apache.mirror.digitalspace.net/ \
	http://apache.mirrorcentral.com/dist/ \
	http://www.rge.com/pub/infosystems/apache/ \
	http://mirrors.ccs.neu.edu/Apache/dist/ \
	http://www.apache.inetcosmos.org/dist/ \
	http://www.ibiblio.org/pub/packages/infosystems/WWW/servers/apache/ \
	http://apache.ttlhost.com/ \
	http://apache.towardex.com/ \
	http://mirrors.theonlinerecordstore.com/apache/ \
	http://apache.oregonstate.edu/ \
	http://mirror.telentente.com/pub/apache/dist/ \
	http://www.tux.org/pub/net/apache/dist/ \
	http://apache.secsup.org/dist/ \
	http://ftp.epix.net/apache/ \
	http://public.planetmirror.com.au/pub/apache/dist/ \
	ftp://ftp.rge.com/pub/infosystems/apache/ \
	ftp://ftp.epix.net/pub/apache/ \
	ftp://ftp.ccs.neu.edu/net/mirrors/Apache/dist/ \
	ftp://ftp.tux.org/pub/net/apache/dist/ \
	ftp://ftp.apache.inetcosmos.org/pub/apache/dist/ \
	ftp://www.ibiblio.org/pub/packages/infosystems/WWW/servers/apache/ \
	ftp://ftp.knowledge.com/pub/mirrors/apache/dist/ \
	ftp://ftp.sunsite.utk.edu/pub/apache/dist/ \
	ftp://ftp.oregonstate.edu/pub/apache/ \
	ftp://apache.secsup.org/pub/apache/dist/ \
	ftp://mirror.telentente.com/pub/apache/dist/ \
	ftp://mirrors.midco.net/pub/apache.org/ \
	http://nagoya.apache.org/mirror/

MASTER_SITE_DEBIAN= \
	http://ftp.debian.org/debian/ \
	http://ftp.at.debian.org/debian/ \
	http://ftp.au.debian.org/debian/ \
	http://ftp.wa.au.debian.org/debian/ \
	http://ftp.bg.debian.org/debian/ \
	http://ftp.br.debian.org/debian/ \
	http://ftp.cl.debian.org/debian/ \
	http://ftp.cz.debian.org/debian/ \
	http://ftp.de.debian.org/debian/ \
	http://ftp2.de.debian.org/debian/ \
	http://ftp.dk.debian.org/debian/ \
	http://ftp.ee.debian.org/debian/ \
	http://ftp.es.debian.org/debian/ \
	http://ftp.fi.debian.org/debian/ \
	http://ftp.fr.debian.org/debian/ \
	http://ftp2.fr.debian.org/debian/ \
	http://ftp.uk.debian.org/debian/ \
	http://ftp.hk.debian.org/debian/ \
	http://ftp.hr.debian.org/debian/ \
	http://ftp.hu.debian.org/debian/ \
	http://ftp.ie.debian.org/debian/ \
	http://ftp.is.debian.org/debian/ \
	http://ftp.it.debian.org/debian/ \
	http://ftp2.it.debian.org/debian/ \
	http://ftp.jp.debian.org/debian/ \
	http://ftp.nl.debian.org/debian/ \
	http://ftp.no.debian.org/debian/ \
	http://ftp.nz.debian.org/debian/ \
	http://ftp.pl.debian.org/debian/ \
	http://ftp.ru.debian.org/debian/ \
	http://ftp.se.debian.org/debian/ \
	http://ftp.si.debian.org/debian/ \
	http://ftp.sk.debian.org/debian/ \
	http://ftp.tr.debian.org/debian/ \
	http://ftp.us.debian.org/debian/

# The primary backup site.
MASTER_SITE_BACKUP=	\
	http://godi-backup2.camlcity.org/godi-backup/ \
	http://www.ocaml-programming.de/godi-backup/

# Where to put distfiles that don't have any other master site
MASTER_SITE_LOCAL= \
	${MASTER_SITE_BACKUP:=LOCAL_PORTS/}

GODI_BUILD_SITE?= \
        http://www.ocaml-programming.de/godi-build/${GODI_SECTION}/
# This must only be one URL.

GODI_BUILD_BACKUP_SITES= \
	http://godi-backup2.camlcity.org/godi-build/${GODI_SECTION}/

GODI_BUILD_SITES= \
	${GODI_BUILD_SITE} \
	${GODI_BUILD_BACKUP_SITES}

GODI_SECTION=	3.08

#----------------------------------------------------------------------
# include the defaults files
#----------------------------------------------------------------------

.undef LOCALBASE

.if exists(${.PARSEDIR}/bsd.pkg.defaults.mk)
.include "${.PARSEDIR}/bsd.pkg.defaults.mk"
.endif

#----------------------------------------------------------------------
# Read user's configuration file
#----------------------------------------------------------------------

# GODI: Here, the NetBSD original of pkgsrc includes <bsd.own.mk>. We
# do not want to have a system-wide installed file like bsd.own.mk, so
# this is replaced by the following.

GODI_CONF?=      ${:!godi_confdir!}/godi.conf
.include "${GODI_CONF}"

# Note: godi_console overrides GODI_CONF to simulate the effects of
# options.

.if !defined(LOCALBASE)
.BEGIN:
	@${ERROR_MSG} "The variable LOCALBASE is not defined in godi.conf!" >&2
	@${ERROR_MSG} "This is a fatal error." >&2
	@false
.endif

.if !defined(GODI_DBDIR)
.BEGIN:
	@${ERROR_MSG} "The variable GODI_DBDIR is not defined in godi.conf!" >&2
	@${ERROR_MSG} "This is a fatal error." >&2
	@false
.endif

#----------------------------------------------------------------------
# Special configuration wishes indicated in godi.conf
#----------------------------------------------------------------------

# Merge SEARCH_LIBS and SEARCH_LIBS_DEFAULT:
.if defined(SEARCH_LIBS_OVERRIDE)
SEARCH_LIBS=	${SEARCH_LIBS_OVERRIDE}
.else
SEARCH_LIBS+=	${SEARCH_LIBS_DEFAULT}
.endif


# If WRKOBJDIR is set, use that tree to build
.if defined(WRKOBJDIR)
BUILD_DIR=		${WRKOBJDIR}/${PKGPATH}
.endif

# If OBJHOSTNAME is set, use first component of hostname in directory name.
# If OBJMACHINE is set, use ${MACHINE_ARCH} in the working directory name.
#
.if defined(OBJHOSTNAME)
.  if !defined(_HOSTNAME)
_HOSTNAME!=		${UNAME} -n
MAKEFLAGS+=		_HOSTNAME="${_HOSTNAME}"
.  endif
WRKDIR_BASENAME=	work.${_HOSTNAME:C|\..*||}
MAKEFLAGS+=		OBJHOSTNAME="${OBJHOSTNAME}"
.elif defined(OBJMACHINE)
WRKDIR_BASENAME=	work.${MACHINE_ARCH}
MAKEFLAGS+=		OBJMACHINE="${OBJMACHINE}"
.endif

# If this host is behind a filtering firewall, use passive ftp(1)
.if defined(PASSIVE_FETCH)
FETCH_BEFORE_ARGS += -p
.endif

# Include the configuration of the O'Caml compiler. This is ocaml.mk,
# config-summary.mk, or a default configuration.
.if exists(${LOCALBASE}/lib/godi/ocaml.mk)
.  include "${LOCALBASE}/lib/godi/ocaml.mk"
.elif exists(${LOCALBASE}/lib/godi/saved-src/config-summary.mk)
.  include "${LOCALBASE}/lib/godi/saved-src/config-summary.mk"
.else
# Set conservative default values for the variables included from config-summary.mk:
GODI_HAVE_OCAMLOPT=	no
GODI_THREAD_MODEL=	bthr
GODI_HAVE_DLL=		no
GODI_HAVE_PROF=		no
.endif

# ${BUILD_OCAMLFIND} invokes the version of ocamlfind that must be
# used at build time:

BUILD_OCAMLFIND_ENV=OCAMLFIND_CONF="${LOCALBASE}/etc/findlib-BUILD.conf"
BUILD_OCAMLFIND=${SETENV} ${BUILD_OCAMLFIND_ENV} "${LOCALBASE}/bin/ocamlfind"

.if defined(PREFIX) && (${PREFIX} != ${__PREFIX_SET__})
.BEGIN:
	@${ERROR_MSG} "You can NOT set PREFIX manually or in godi.conf.  Set LOCALBASE"
	@${ERROR_MSG} "depending on your needs.  See the pkg system documentation for more info."
	@${FALSE}
.endif

#----------------------------------------------------------------------
# sys.mk
#----------------------------------------------------------------------

# Preload all default values for CFLAGS, LDFLAGS, etc. before bsd.pkg.mk
# or a pkg Makefile modifies them.
.include <sys.mk>

#----------------------------------------------------------------------
# Another way to override variables
#----------------------------------------------------------------------

.if defined(GODI_OVERRIDE_PREFS)
.include "${GODI_OVERRIDE_PREFS}"
.endif

.endif	# BSD_PKG_MK
